@@ -213,8 +213,7 @@ void Interfile::downloadCaptcha() {
 }
 
 void Interfile::submitCaptchaResponse(const QString &challenge, const QString &response) {
-    Q_UNUSED(challenge)
-    QString data = QString("op=download2&id=%1&rand=%2&method_free=Download at speed 50 Kb/sec&code=%3&down_direct=1").arg(m_fileId).arg(m_rand).arg(response);
+    QString data = QString("op=download2&id=%1&rand=%2&method_free=Download at speed 50 Kb/sec&code=%3&down_direct=1").arg(m_fileId).arg(challenge).arg(response);
     QNetworkRequest request(m_url);
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     QNetworkReply *reply = this->networkAccessManager()->post(request, data.toUtf8());
